#!/usr/bin/env python3

# This file is part of Remote Support Desktop
# https://gitlab.das-netzwerkteam.de/RemoteWebApp/rwa.support.sessionservice
# Copyright 2020, 2021 Jonathan Weth <dev@jonathanweth.de>
# Copyright 2020, 2021 Daniel Teichmann <daniel.teichmann@das-netzwerkteam.de>
# Copyright 2020 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
# SPDX-License-Identifier: GPL-2.0-or-later
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the
# Free Software Foundation, Inc.,
# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.


import click
import dbus

try:
    bus = dbus.SessionBus()
    req = bus.get_object("org.ArcticaProject.RWASupportSessionService", "/RWASupportSessionService")
except dbus.exceptions.DBusException:
    click.echo("The D-Bus service isn't responding! Is it even started? Aborting ...")
    exit(1)


@click.group()
def cli():
    pass


@cli.command()
def get_web_app_hosts():
    """Get all RWA.Support.WebApp hosts"""
    click.echo("Sending D-Bus request 'get_web_app_hosts.'")
    response = req.get_web_app_hosts()
    click.echo(f"Your response is: {response}")


@cli.command()
@click.argument("host", type=str)
def add_web_app_host(host: str):
    """Add a RWA.Support.WebApp host. Requires <url>"""
    click.echo(f"Sending D-Bus request 'add_web_app_host': {host}")
    response = req.add_web_app_host(host)
    click.echo(f"Your response is: {response}")


@cli.command()
@click.argument("host", type=str)
def remove_web_app_host(host: str):
    """Remove a RWA.Support.WebApp host. Requires <host_uuid>"""
    click.echo(f"Sending D-Bus request 'remove_web_app_host': {host}")
    response = req.remove_web_app_host(host)
    click.echo(f"Your response is: {response}")


@cli.command()
@click.argument("host_uuid", type=str)
def start(host_uuid: str):
    """Start a session on the RWA.Support.WebApp host. Requires <host_uuid>"""
    click.echo(f"Sending D-Bus request 'start': {host_uuid}")
    response = req.start(host_uuid)
    click.echo(f"Your response is: {response}")


@cli.command()
@click.argument("host_uuid", type=str)
@click.argument("session_id", type=int)
def stop(host_uuid: str, session_id: int):
    """Stop a session on the RWA.Support.WebApp host. Requires <host_uuid> <session_id>"""
    click.echo(f"Sending D-Bus request 'stop' with host ID {host_uuid} and session ID {session_id}")
    response = req.stop(host_uuid, session_id)
    click.echo(f"Your response is: {response}")


@cli.command()
@click.argument("host_uuid", type=str)
@click.argument("session_id", type=int)
def status(host_uuid: str, session_id: int):
    """Get the status of a session. Requires <host_uuid> <session_id>"""
    click.echo(f"Sending D-Bus request 'status' with host ID {host_uuid} and session ID {session_id}")
    response = req.status(host_uuid, session_id)
    click.echo(f"Your response is: {response}")


@cli.command()
@click.argument("host_uuid", type=str)
@click.argument("session_id", type=int)
def refresh_status(host_uuid: str, session_id: int):
    """Refresh and then get the status of a session. Requires <host_uuid> <session_id>"""
    click.echo(
        f"Sending D-Bus request 'refresh_status' with host ID {host_uuid} and session ID {session_id}"
    )
    response = req.refresh_status(host_uuid, session_id)
    click.echo(f"Your response is: {response}")


if __name__ == "__main__":
    cli()
